@@ -209,7 +209,7 @@ def getDOB(text: str):
         dob = ""
     return dob
 
-def getFeeSheet(text: str, cnum=''):
+def getFeeSheet(text: str):
     actives = re.findall(r'(ACTIVE.*\$.*)', str(text))
     if len(actives) == 0:
         return [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan]
@@ -245,7 +245,7 @@ def getFeeSheet(text: str, cnum=''):
         
 
         feesheet = pd.DataFrame({
-            'CaseNumber': cnum,
+            'CaseNumber': getCaseNumber(text),
             'Total': '',
             'FeeStatus': 'ACTIVE',
             'AdminFee': adminfeerows.tolist(),
@@ -258,7 +258,7 @@ def getFeeSheet(text: str, cnum=''):
             })
 
         totalrdf = {
-            'CaseNumber': cnum,
+            'CaseNumber': getCaseNumber(text),
             'Total': 'TOTAL',
             'FeeStatus': '',
             'AdminFee': '',
@@ -382,8 +382,9 @@ def getAmtPaidByCode(text: str, code: str):
 
     paid = codemap.AmtPaid[codemap.Code == code]
     return paid
-def getCharges(text: str, cnum=''):
 
+def getCharges(text: str):
+    cnum = getCaseNumber(text)
     rc = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{10,75})', text, re.MULTILINE)
     unclean = pd.DataFrame({'Raw':rc})
     unclean['FailTimeTest'] = unclean['Raw'].map(lambda x: bool(re.search(r'([0-9]{1}\:[0-9]{2})', x)))
@@ -399,6 +400,7 @@ def getCharges(text: str, cnum=''):
     c = passed.dropna().tolist()
     cind = range(0, len(c))
     charges = pd.DataFrame({ 'Charges': c,'parentheses':'','decimals':''},index=cind)
+    charges['Charges'] = charges['Charges'].map(lambda x: re.sub(r'(©.+)','',x,re.MULTILINE))
     charges['CaseNumber'] = charges.index.map(lambda x: cnum)
     split_charges = charges['Charges'].map(lambda x: x.split(" "))
     charges['Num'] = split_charges.map(lambda x: x[0].strip())
@@ -414,7 +416,7 @@ def getCharges(text: str, cnum=''):
     charges['Permanent'] = charges.index.map(lambda x: charges['PermanentCode'][x] == True and charges['VRRexception'][x] == False and charges['Felony'][x] == True)
     charges['Disposition'] = charges['Charges'].map(lambda x: bool(re.search(r'\d{2}/\d{2}/\d{4}', x)))
     charges['CourtActionDate'] = charges['Charges'].map(lambda x: re.search(r'(\d{2}/\d{2}/\d{4})', x).group() if bool(re.search(r'(\d{2}/\d{2}/\d{4})', x)) else "")
-    charges['CourtAction'] = charges['Charges'].map(lambda x: re.search(r'(BOUND|GUILTY PLEA|PROBATION|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|OTHER|DISMISSED|FORFEITURE|TRANSFER|REMANDED|PROBATION|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x).group() if bool(re.search(r'(BOUND|GUILTY PLEA|PROBATION|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|OTHER|DISMISSED|FORFEITURE|TRANSFER|REMANDED|PROBATION|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x)) else "")
+    charges['CourtAction'] = charges['Charges'].map(lambda x: re.search(r'(BOUND|GUILTY PLEA|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x).group() if bool(re.search(r'(BOUND|GUILTY PLEA|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x)) else "")
     try:
         charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^a-z]{1,2}?.{1}-[^\s]{3}-[^\s]{3})', x).group())
     except (AttributeError, IndexError):
@@ -517,6 +519,7 @@ def getCharges(text: str, cnum=''):
 
 
     return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, allcharge, charges]
+
 def getConvictions(text) -> str:
     return getCharges(text)[0]
 def getDispositionCharges(text) -> str:
@@ -549,12 +552,12 @@ def getChargeCodes(text) -> [str]:
     return getCharges(text)[14]
 def getConvictionCodes(text) -> [str]:
     return getCharges(text)[15]
-def getCharges_str(text) -> str:
+def getChargesString(text) -> str:
     return getCharges(text)[16]
 
 
 
-def config(input_path, table_path=None, archive_path=None, text_path=None, tables="", print_log=True, verbose=True, warn=False, max_cases=0, force_overwrite=True, GUI_mode=False, drop_cols=True): 
+def config(input_path, table_path=None, archive_path=None, text_path=None, tables="", print_log=True, verbose=False, warn=False, max_cases=0, force_overwrite=True, GUI_mode=False, drop_cols=True): 
 
     tab_ext = ""
     arc_ext = ""
@@ -563,13 +566,21 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
     stringInput = True
     pathMode = False
     old_archive = None
+    old_table = None
 
     if warn == False:
         warnings.filterwarnings("ignore")
 
 ## CONFIG - INPUT
 
-    ## FILE INPUT (.PDF, .TXT, .PKL.XZ)
+    ## OBJECT INPUT
+
+    if archive_path == None and os.path.splitext(table_path)[1] == ".xz":
+        archive_path = table_path
+        table_path = None
+        if log:
+            print(f"WARNING: alac.config() received archive file format for parameter table_path: Setting archive_path to {archive_path}. Reconfigure to export tables.")
+
 
     if isinstance(input_path, pd.core.series.Series) or isinstance(input_path, pd.core.frame.DataFrame):
         obj_in = input_path
@@ -580,6 +591,8 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         else:
             raise Exception("Object input only supports archives! Must use \'AllPagesText\' series to continue.")
 
+    ## EXISTING FILE INPUT
+
     if os.path.isfile(input_path): 
         in_head = os.path.split(input_path)[0]
         in_tail = os.path.split(input_path)[1]
@@ -650,15 +663,11 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         arc_tail = os.path.split(archive_path)[1]
         arc_ext = os.path.splitext(arc_tail)[1]
         if arc_ext == ".xz": # if archive 
-            if os.path.isfile(archive_path):
-                try: # if exists at path, append
-                    old_archive = pd.read_pickle(archive_path,compression="xz")
-                    appendArchive = True
-                except: 
-                    raise Exception("Invalid archive output path!")
-            else:
-                old_archive = None
-                appendArchive = False
+            try: # if exists at path, append
+                old_archive = pd.read_pickle(archive_path,compression="xz")
+                appendArchive = True
+            except: 
+                pass
         else:
             raise Exception("Invalid file extension! Archives must export to .pkl.xz")
 
@@ -683,13 +692,10 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         elif tab_ext == ".xz" or tab_ext == ".json" or tab_ext == ".xls" or tab_ext == ".xlsx" or tab_ext == ".csv" or tab_ext == ".txt" or tab_ext == ".pkl" or tab_ext == ".dta":
             pass
         else:
-            raise Exception("Invalid table output file extension! Must write to .xls, .xlsx, .pkl.xz, .csv, .json, or .dta.")
-
-    if table_path != None and archive_path != None and table_path == archive_path:
-        raise Exception("Cannot write tables and archive to same file!")
+            raise Exception("Invalid table output file extension! Must write to .xls, .xlsx, .csv, .json, or .dta.")
 
 ## CONFIG - LOG INPUT 
-    if print_log and verbose:
+    if print_log == True and verbose == True:
         if table_path == None and archive_path == None:
             if GUI_mode == False:
                 print(f"\nNo output path provided. alac.parse...() functions will {'print to console and' if print_log else ''} return object.")
@@ -703,7 +709,7 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
             print(f">>    TABLES:  {'cases, charges, fees' if tables == '' else tables} to {table_path}")
         if archive_path != None:
             print(f">>    ARCHIVE:  {'cases, charges, fees' if tables == '' else tables} to {'existing archive at: ' if appendArchive else ''}{archive_path}\n\n")
-        print("\n")
+        print("\n")        
 
 ## CONFIG OBJECT
     return pd.Series({
@@ -715,6 +721,7 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         'archive_ext': arc_ext,
         'appendArchive': appendArchive, 
         'old_archive': old_archive,
+        'old_table': old_table,
         'warn': warn, 
         'log': print_log,
         'verbose': verbose, 
@@ -734,8 +741,7 @@ def splitext(path: str):
         'ext': ext
     })
 
-
-def checkPath(path: str):
+def checkPath(path: str, log=True):
     PathType = ""
     if os.path.isdir(path):
         count = len(glob.glob(path + '**/*.pdf', recursive=True))
@@ -744,6 +750,8 @@ def checkPath(path: str):
             warnings.warn("No PDFs found in input path!")
         if count > 0:
             PathType = "pdf_directory"
+            if log:
+                print(f"\nAlacorder found {count} PDFs in input directory.")
             return PathType
     else:
         head = os.path.split(path)[0]
@@ -758,27 +766,38 @@ def checkPath(path: str):
         if os.path.isfile(path):
             if ext == ".txt":
                 PathType = "text"
+                if log:
+                    print(f"WARNING: text file input experimental!")
             if ext == ".pdf":
                 PathType = "pdf"
             if ext == ".xz":
                 test = pd.read_pickle(path,compression="xz")
                 if "AllPagesText" in test.columns:
                     PathType = "existing_archive"
+                    if log:
+                        print(f"Found existing archive with {test.shape[0]} cases. APPEND MODE is enabled.")
                     return PathType
                 else:
                     PathType = "overwrite_archive"
-                    warnings.warn("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
+                    if log:
+                        print("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                     return PathType
             elif ext == ".xls" or ext == ".xlsx":
+                if log:
+                    print("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                 PathType = "overwrite_all_tables"
                 return PathType
             elif ext == ".csv" or ext == ".json" or ext == ".dta":
+                if log:
+                    print("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                 PathType = "overwrite_table"
                 return PathType
             else:
                 PathType = "bad"
-                warnings.warn("Output file extension not supported!")
-                warnings.warn("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
+                if log:
+                    print("Output file extension not supported!")
+                if log:
+                    print("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                 return PathType
         else:
             if ext == ".xls" or ext == ".xlsx":
@@ -798,6 +817,12 @@ def checkPath(path: str):
 
 def write(conf, outputs, archive=False):
     max_cases = conf['count']
+    old_archive = conf['old_archive']
+    if isinstance(old_archive, pd.core.frame.DataFrame):
+        try:
+            outputs = old_archive.append(outputs)
+        except (AttributeError, TypeError):
+          outputs = pd.Series([old_archive, outputs])
     if archive:
         path_out = conf['archive_out']
     else:
@@ -876,6 +901,8 @@ def writeArchive(conf):
     warn = conf['warn']
     path_mode = conf['path_mode']
     max_cases = conf['count']
+    old_archive = conf['old_archive']
+
     start_time = time.time()
     if warn == False:
         warnings.filterwarnings("ignore")
@@ -891,8 +918,13 @@ def writeArchive(conf):
         'Timestamp': start_time
         })
 
-    outputs.fillna('',inplace=True)
+    if isinstance(old_archive, pd.core.frame.DataFrame):
+        try:
+            outputs = old_archive.append(outputs)
+        except:
+            outputs = [old_archive, outputs]
 
+    outputs.fillna('',inplace=True)
     write(conf, outputs, archive=True)
     log_complete(conf, start_time)
     return outputs
@@ -932,7 +964,7 @@ def parseFees(conf):
 
         b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: getCaseInfo(x))
         b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
-        b['FeeOutputs'] = b.index.map(lambda x: getFeeSheet(b.loc[x].AllPagesText, b.loc[x].CaseNumber))
+        b['FeeOutputs'] = b.index.map(lambda x: getFeeSheet(b.loc[x].AllPagesText))
 
         feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
         feesheet = feesheet.dropna() # drop empty 
@@ -955,7 +987,6 @@ def parseFees(conf):
 
 def getPaymentToRestore(text: str):
     totalrow = "".join(re.findall(r'(Total.*\$.+\$.+\$.+)', str(text), re.MULTILINE)) if bool(re.search(r'(Total.*\$.*)', str(text), re.MULTILINE)) else "0"
-    # totalrow = re.sub(r'[^0-9|\.|\s|\$]', "", trowraw)
     try:
         tbalance = totalrow.split("$")[3].strip().replace("$","").replace(",","").replace(" ","").strip()
         try:
@@ -1007,7 +1038,7 @@ def parseCharges(conf):
 
         b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: getCaseInfo(x))
         b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
-        b['ChargesOutputs'] = b.index.map(lambda x: getCharges(b.loc[x].AllPagesText, b.loc[x].CaseNumber))
+        b['ChargesOutputs'] = b.index.map(lambda x: getCharges(b.loc[x].AllPagesText))
 
         
         chargetabs = b['ChargesOutputs'].map(lambda x: x[17])
@@ -1083,7 +1114,7 @@ def parseCases(conf):
         b['Sex'] = b['CaseInfoOutputs'].map(lambda x: x[5])
         b['Address'] = b['CaseInfoOutputs'].map(lambda x: x[6])
         b['Phone'] = b['CaseInfoOutputs'].map(lambda x: x[7])
-        b['ChargesOutputs'] = b.index.map(lambda x: getCharges(b.loc[x].AllPagesText, b.loc[x].CaseNumber))
+        b['ChargesOutputs'] = b.index.map(lambda x: getCharges(b.loc[x].AllPagesText))
         b['Convictions'] = b['ChargesOutputs'].map(lambda x: x[0])
         b['DispositionCharges'] = b['ChargesOutputs'].map(lambda x: x[1])
         b['FilingCharges'] = b['ChargesOutputs'].map(lambda x: x[2])
@@ -1100,7 +1131,7 @@ def parseCases(conf):
         b['PermanentConvictionCount'] = b['ChargesOutputs'].map(lambda x: x[13])
         b['ChargeCodes'] = b['ChargesOutputs'].map(lambda x: x[14])
         b['ConvictionCodes'] = b['ChargesOutputs'].map(lambda x: x[15])
-        b['FeeOutputs'] = b.index.map(lambda x: getFeeSheet(b.loc[x].AllPagesText, b.loc[x].CaseNumber))
+        b['FeeOutputs'] = b.index.map(lambda x: getFeeSheet(b.loc[x].AllPagesText))
         b['TotalAmtDue'] = b['FeeOutputs'].map(lambda x: x[0])
         b['TotalBalance'] = b['FeeOutputs'].map(lambda x: x[1])
         b['PaymentToRestore'] = b['AllPagesText'].map(lambda x: getPaymentToRestore(x))
@@ -1399,4 +1430,14 @@ def log_console(conf, *msg):
 
     if print_log:
         print(msg)
+        print(f'''
+
+>>  ALACORDER PROGRESS:
+
+    >>    INPUT: {path_in} 
+    >>    OUTPUT: {path_out} 
+    >>    ARCHIVE: {arc_out}
+
+        
+        ''') 
 
